@@ -1,8 +1,3 @@
-"""
-Author: barbacbd
-Date:   4/20/2020
-"""
-
 import unittest
 from ..web import get_noaa_forecast_url, get_url_source
 from bs4 import BeautifulSoup
