@@ -1,7 +1,3 @@
-"""
-Author: barbacbd
-Date:   5/12/2020
-"""
 # Not sure why but this is the default value for NOAA data that is not present.
 # There may be times where we check against this value for validity/availability
 UNAVAILABLE_NOAA_DATA = "-"
