@@ -1,7 +1,3 @@
-"""
-Author: barbacbd
-Date:   4/18/2020
-"""
 from .conversion import *
 from .nautical_time import *
 from .enums import *
